@@ -3,7 +3,10 @@
 
 import re
 page_pattern = re.compile('^%%Page: [0-9]+ [0-9]+$')
-subseq_pattern = re.compile('(Seite [0-9]+ von [0-9]+ - Rechnung Nr. [0-9]+)')
+subseq_patterns = dict(
+    de=re.compile('(Seite [0-9]+ von [0-9]+ - Rechnung Nr. [0-9]+)'),
+    en=re.compile('(Page [0-9]+ of [0-9]+ - Invoice No. [0-9]+)'),
+    )
 beginpagesetup_pattern = re.compile('^%%BeginPageSetup$')
 endpagesetup_pattern = re.compile('^%%EndPageSetup$')
 pdfstartpage_pattern = re.compile('^pdfStartPage$')
@@ -24,7 +27,8 @@ def insert_tray_directives(lines, tray1, tray2):
 
     for page in pages[1:]:
         for line in page:
-            if subseq_pattern.search(line):
+            if any(pattern.search(line)
+                   for pattern in subseq_patterns.itervalues()):
                 tray = tray2
                 break
         else:
